@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -73,7 +73,7 @@ int do_file ( const char *in_name, int level )
 	int r;
 	lzo_byte *in;
 	lzo_byte *out;
-	lzo_byte *new;
+	lzo_byte *newb;
 	lzo_byte *wrkmem;
 	lzo_uint in_len;
 	lzo_uint out_len;
@@ -106,9 +106,9 @@ int do_file ( const char *in_name, int level )
  */
 	in = lzo_malloc(in_len);
 	out = lzo_malloc(in_len + in_len / 64 + 16 + 3);
-	new = lzo_malloc(in_len);
+	newb = lzo_malloc(in_len);
 	wrkmem = lzo_malloc(LZO1X_999_MEM_COMPRESS);
-	if (in == NULL || out == NULL || new == NULL || wrkmem == NULL)
+	if (in == NULL || out == NULL || newb == NULL || wrkmem == NULL)
 	{
 		printf("%s: out of memory\n", progname);
 		exit(1);
@@ -131,10 +131,10 @@ int do_file ( const char *in_name, int level )
 	print_file(in_name,in_len,out_len);
 
 /*
- * Step 4: decompress again, now going from `out' to `new'
+ * Step 4: decompress again, now going from `out' to `newb'
  */
  	new_len = in_len;
-	r = lzo1x_decompress_dict_safe(out,out_len,new,&new_len,NULL,dict,dict_len);
+	r = lzo1x_decompress_dict_safe(out,out_len,newb,&new_len,NULL,dict,dict_len);
 	if (r != LZO_E_OK)
 	{
 		/* this should NEVER happen */
@@ -145,7 +145,7 @@ int do_file ( const char *in_name, int level )
 /*
  * Step 5: verify decompression
  */
-	if (new_len != in_len || lzo_memcmp(in,new,in_len) != 0)
+	if (new_len != in_len || lzo_memcmp(in,newb,in_len) != 0)
 	{
 		/* this should NEVER happen */
 		printf("internal error - decompression data error\n");
@@ -154,7 +154,7 @@ int do_file ( const char *in_name, int level )
 
 	/* free buffers in reverse order to help malloc() */
 	lzo_free(wrkmem);
-	lzo_free(new);
+	lzo_free(newb);
 	lzo_free(out);
 	lzo_free(in);
 	return 0;
@@ -180,8 +180,8 @@ int main(int argc, char *argv[])
 #endif
 
 	printf("\nLZO real-time data compression library (v%s, %s).\n",
-	        LZO_VERSION_STRING, LZO_VERSION_DATE);
-	printf("Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer\n\n");
+	        lzo_version_string(), lzo_version_date());
+	printf("Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer\n\n");
 
 	progname = argv[0];
 
