@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -95,7 +95,7 @@ int main(int argc, char *argv[])
 	lzo_uint in_len;
 
 	lzo_byte *out;
-	lzo_uint out_len;
+	lzo_uint out_len = 0;
 
 	lzo_byte *wrkmem;
 	lzo_uint wrk_len;
@@ -121,8 +121,8 @@ int main(int argc, char *argv[])
 #endif
 
 	printf("\nLZO real-time data compression library (v%s, %s).\n",
-	        LZO_VERSION_STRING, LZO_VERSION_DATE);
-	printf("Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer\n\n");
+	        lzo_version_string(), lzo_version_date());
+	printf("Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer\n\n");
 
 	progname = argv[0];
 	if (argc < 2 || argc > 3)
