@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -34,12 +34,14 @@
   lzo1_compress,                0,
   lzo1_decompress,              0,
   0,                            0,
+  0,                            0,
   0,                            0 },
 #if !defined(LZO_99_UNSUPPORTED)
 { "LZO1-99", M_LZO1_99, LZO1_99_MEM_COMPRESS, LZO1_MEM_DECOMPRESS,
   lzo1_99_compress,             0,
   lzo1_decompress,              0,
   0,                            0,
+  0,                            0,
   0,                            0 },
 #endif
 #endif
@@ -49,12 +51,14 @@
   lzo1a_compress,               0,
   lzo1a_decompress,             0,
   0,                            0,
+  0,                            0,
   0,                            0 },
 #if !defined(LZO_99_UNSUPPORTED)
 { "LZO1A-99", M_LZO1A_99, LZO1A_99_MEM_COMPRESS, LZO1A_MEM_DECOMPRESS,
   lzo1a_99_compress,            0,
   lzo1a_decompress,             0,
   0,                            0,
+  0,                            0,
   0,                            0 },
 #endif
 #endif
@@ -64,60 +68,71 @@
   lzo1b_1_compress,             0,
   lzo1b_decompress,             lzo1b_decompress_safe,
   lzo1b_decompress_asm,         lzo1b_decompress_asm_safe,
-  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe },
+  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe,
+  0,                            0 },
 { "LZO1B-2", M_LZO1B_2, LZO1B_MEM_COMPRESS, LZO1B_MEM_DECOMPRESS,
   lzo1b_2_compress,             0,
   lzo1b_decompress,             lzo1b_decompress_safe,
   lzo1b_decompress_asm,         lzo1b_decompress_asm_safe,
-  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe },
+  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe,
+  0,                            0 },
 { "LZO1B-3", M_LZO1B_3, LZO1B_MEM_COMPRESS, LZO1B_MEM_DECOMPRESS,
   lzo1b_3_compress,             0,
   lzo1b_decompress,             lzo1b_decompress_safe,
   lzo1b_decompress_asm,         lzo1b_decompress_asm_safe,
-  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe },
+  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe,
+  0,                            0 },
 { "LZO1B-4", M_LZO1B_4, LZO1B_MEM_COMPRESS, LZO1B_MEM_DECOMPRESS,
   lzo1b_4_compress,             0,
   lzo1b_decompress,             lzo1b_decompress_safe,
   lzo1b_decompress_asm,         lzo1b_decompress_asm_safe,
-  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe },
+  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe,
+  0,                            0 },
 { "LZO1B-5", M_LZO1B_5, LZO1B_MEM_COMPRESS, LZO1B_MEM_DECOMPRESS,
   lzo1b_5_compress,             0,
   lzo1b_decompress,             lzo1b_decompress_safe,
   lzo1b_decompress_asm,         lzo1b_decompress_asm_safe,
-  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe },
+  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe,
+  0,                            0 },
 { "LZO1B-6", M_LZO1B_6, LZO1B_MEM_COMPRESS, LZO1B_MEM_DECOMPRESS,
   lzo1b_6_compress,             0,
   lzo1b_decompress,             lzo1b_decompress_safe,
   lzo1b_decompress_asm,         lzo1b_decompress_asm_safe,
-  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe },
+  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe,
+  0,                            0 },
 { "LZO1B-7", M_LZO1B_7, LZO1B_MEM_COMPRESS, LZO1B_MEM_DECOMPRESS,
   lzo1b_7_compress,             0,
   lzo1b_decompress,             lzo1b_decompress_safe,
   lzo1b_decompress_asm,         lzo1b_decompress_asm_safe,
-  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe },
+  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe,
+  0,                            0 },
 { "LZO1B-8", M_LZO1B_8, LZO1B_MEM_COMPRESS, LZO1B_MEM_DECOMPRESS,
   lzo1b_8_compress,             0,
   lzo1b_decompress,             lzo1b_decompress_safe,
   lzo1b_decompress_asm,         lzo1b_decompress_asm_safe,
-  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe },
+  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe,
+  0,                            0 },
 { "LZO1B-9", M_LZO1B_9, LZO1B_MEM_COMPRESS, LZO1B_MEM_DECOMPRESS,
   lzo1b_9_compress,             0,
   lzo1b_decompress,             lzo1b_decompress_safe,
   lzo1b_decompress_asm,         lzo1b_decompress_asm_safe,
-  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe },
+  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe,
+  0,                            0 },
 #if !defined(LZO_99_UNSUPPORTED)
 { "LZO1B-99", M_LZO1B_99, LZO1B_99_MEM_COMPRESS, LZO1B_MEM_DECOMPRESS,
   lzo1b_99_compress,            0,
   lzo1b_decompress,             lzo1b_decompress_safe,
   lzo1b_decompress_asm,         lzo1b_decompress_asm_safe,
-  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe },
+  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe,
+  0,                            0 },
 #endif
 #if !defined(LZO_999_UNSUPPORTED)
 { "LZO1B-999", M_LZO1B_999, LZO1B_999_MEM_COMPRESS, LZO1B_MEM_DECOMPRESS,
   lzo1b_999_compress,           0,
   lzo1b_decompress,             lzo1b_decompress_safe,
   lzo1b_decompress_asm,         lzo1b_decompress_asm_safe,
-  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe },
+  lzo1b_decompress_asm_fast,    lzo1b_decompress_asm_fast_safe,
+  0,                            0 },
 #endif
 #endif
 
@@ -126,60 +141,71 @@
   lzo1c_1_compress,             0,
   lzo1c_decompress,             lzo1c_decompress_safe,
   lzo1c_decompress_asm,         lzo1c_decompress_asm_safe,
-  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe },
+  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe,
+  0,                            0 },
 { "LZO1C-2", M_LZO1C_2, LZO1C_MEM_COMPRESS, LZO1C_MEM_DECOMPRESS,
   lzo1c_2_compress,             0,
   lzo1c_decompress,             lzo1c_decompress_safe,
   lzo1c_decompress_asm,         lzo1c_decompress_asm_safe,
-  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe },
+  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe,
+  0,                            0 },
 { "LZO1C-3", M_LZO1C_3, LZO1C_MEM_COMPRESS, LZO1C_MEM_DECOMPRESS,
   lzo1c_3_compress,             0,
   lzo1c_decompress,             lzo1c_decompress_safe,
   lzo1c_decompress_asm,         lzo1c_decompress_asm_safe,
-  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe },
+  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe,
+  0,                            0 },
 { "LZO1C-4", M_LZO1C_4, LZO1C_MEM_COMPRESS, LZO1C_MEM_DECOMPRESS,
   lzo1c_4_compress,             0,
   lzo1c_decompress,             lzo1c_decompress_safe,
   lzo1c_decompress_asm,         lzo1c_decompress_asm_safe,
-  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe },
+  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe,
+  0,                            0 },
 { "LZO1C-5", M_LZO1C_5, LZO1C_MEM_COMPRESS, LZO1C_MEM_DECOMPRESS,
   lzo1c_5_compress,             0,
   lzo1c_decompress,             lzo1c_decompress_safe,
   lzo1c_decompress_asm,         lzo1c_decompress_asm_safe,
-  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe },
+  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe,
+  0,                            0 },
 { "LZO1C-6", M_LZO1C_6, LZO1C_MEM_COMPRESS, LZO1C_MEM_DECOMPRESS,
   lzo1c_6_compress,             0,
   lzo1c_decompress,             lzo1c_decompress_safe,
   lzo1c_decompress_asm,         lzo1c_decompress_asm_safe,
-  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe },
+  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe,
+  0,                            0 },
 { "LZO1C-7", M_LZO1C_7, LZO1C_MEM_COMPRESS, LZO1C_MEM_DECOMPRESS,
   lzo1c_7_compress,             0,
   lzo1c_decompress,             lzo1c_decompress_safe,
   lzo1c_decompress_asm,         lzo1c_decompress_asm_safe,
-  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe },
+  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe,
+  0,                            0 },
 { "LZO1C-8", M_LZO1C_8, LZO1C_MEM_COMPRESS, LZO1C_MEM_DECOMPRESS,
   lzo1c_8_compress,             0,
   lzo1c_decompress,             lzo1c_decompress_safe,
   lzo1c_decompress_asm,         lzo1c_decompress_asm_safe,
-  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe },
+  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe,
+  0,                            0 },
 { "LZO1C-9", M_LZO1C_9, LZO1C_MEM_COMPRESS, LZO1C_MEM_DECOMPRESS,
   lzo1c_9_compress,             0,
   lzo1c_decompress,             lzo1c_decompress_safe,
   lzo1c_decompress_asm,         lzo1c_decompress_asm_safe,
-  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe },
+  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe,
+  0,                            0 },
 #if !defined(LZO_99_UNSUPPORTED)
 { "LZO1C-99", M_LZO1C_99, LZO1C_99_MEM_COMPRESS, LZO1C_MEM_DECOMPRESS,
   lzo1c_99_compress,            0,
   lzo1c_decompress,             lzo1c_decompress_safe,
   lzo1c_decompress_asm,         lzo1c_decompress_asm_safe,
-  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe },
+  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe,
+  0,                            0 },
 #endif
 #if !defined(LZO_999_UNSUPPORTED)
 { "LZO1C-999", M_LZO1C_999, LZO1C_999_MEM_COMPRESS, LZO1C_MEM_DECOMPRESS,
   lzo1c_999_compress,           0,
   lzo1c_decompress,             lzo1c_decompress_safe,
   lzo1c_decompress_asm,         lzo1c_decompress_asm_safe,
-  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe },
+  lzo1c_decompress_asm_fast,    lzo1c_decompress_asm_fast_safe,
+  0,                            0 },
 #endif
 #endif
 
@@ -188,13 +214,15 @@
   lzo1f_1_compress,             0,
   lzo1f_decompress,             lzo1f_decompress_safe,
   lzo1f_decompress_asm,         lzo1f_decompress_asm_safe,
-  lzo1f_decompress_asm_fast,    lzo1f_decompress_asm_fast_safe },
+  lzo1f_decompress_asm_fast,    lzo1f_decompress_asm_fast_safe,
+  0,                            0 },
 #if !defined(LZO_999_UNSUPPORTED)
 { "LZO1F-999", M_LZO1F_999, LZO1F_999_MEM_COMPRESS, LZO1F_MEM_DECOMPRESS,
   lzo1f_999_compress,           0,
   lzo1f_decompress,             lzo1f_decompress_safe,
   lzo1f_decompress_asm,         lzo1f_decompress_asm_safe,
-  lzo1f_decompress_asm_fast,    lzo1f_decompress_asm_fast_safe },
+  lzo1f_decompress_asm_fast,    lzo1f_decompress_asm_fast_safe,
+  0,                            0 },
 #endif
 #endif
 
@@ -387,6 +415,7 @@
   lzo2a_999_compress,           0,
   lzo2a_decompress,             lzo2a_decompress_safe,
   0,                            0,
+  0,                            0,
   0,                            0 },
 #endif
 #endif
@@ -394,46 +423,46 @@
 #if defined(HAVE_ZLIB_H)
 { "zlib-8/1", M_ZLIB_8_1, ZLIB_MEM_COMPRESS, ZLIB_MEM_DECOMPRESS,
                                 zlib_8_1_compress, 0,
-                                zlib_decompress, 0, 0, 0, 0, 0 },
+                                zlib_decompress, 0, 0, 0, 0, 0, 0, 0 },
 { "zlib-8/2", M_ZLIB_8_2, ZLIB_MEM_COMPRESS, ZLIB_MEM_DECOMPRESS,
                                 zlib_8_2_compress, 0,
-                                zlib_decompress, 0, 0, 0, 0, 0 },
+                                zlib_decompress, 0, 0, 0, 0, 0, 0, 0 },
 { "zlib-8/3", M_ZLIB_8_3, ZLIB_MEM_COMPRESS, ZLIB_MEM_DECOMPRESS,
                                 zlib_8_3_compress, 0,
-                                zlib_decompress, 0, 0, 0, 0, 0 },
+                                zlib_decompress, 0, 0, 0, 0, 0, 0, 0 },
 { "zlib-8/4", M_ZLIB_8_4, ZLIB_MEM_COMPRESS, ZLIB_MEM_DECOMPRESS,
                                 zlib_8_4_compress, 0,
-                                zlib_decompress, 0, 0, 0, 0, 0 },
+                                zlib_decompress, 0, 0, 0, 0, 0, 0, 0 },
 { "zlib-8/5", M_ZLIB_8_5, ZLIB_MEM_COMPRESS, ZLIB_MEM_DECOMPRESS,
                                 zlib_8_5_compress, 0,
-                                zlib_decompress, 0, 0, 0, 0, 0 },
+                                zlib_decompress, 0, 0, 0, 0, 0, 0, 0 },
 { "zlib-8/6", M_ZLIB_8_6, ZLIB_MEM_COMPRESS, ZLIB_MEM_DECOMPRESS,
                                 zlib_8_6_compress, 0,
-                                zlib_decompress, 0, 0, 0, 0, 0 },
+                                zlib_decompress, 0, 0, 0, 0, 0, 0, 0 },
 { "zlib-8/7", M_ZLIB_8_7, ZLIB_MEM_COMPRESS, ZLIB_MEM_DECOMPRESS,
                                 zlib_8_7_compress, 0,
-                                zlib_decompress, 0, 0, 0, 0, 0 },
+                                zlib_decompress, 0, 0, 0, 0, 0, 0, 0 },
 { "zlib-8/8", M_ZLIB_8_8, ZLIB_MEM_COMPRESS, ZLIB_MEM_DECOMPRESS,
                                 zlib_8_8_compress, 0,
-                                zlib_decompress, 0, 0, 0, 0, 0 },
+                                zlib_decompress, 0, 0, 0, 0, 0, 0, 0 },
 { "zlib-8/9", M_ZLIB_8_9, ZLIB_MEM_COMPRESS, ZLIB_MEM_DECOMPRESS,
                                 zlib_8_9_compress, 0,
-                                zlib_decompress, 0, 0, 0, 0, 0 },
+                                zlib_decompress, 0, 0, 0, 0, 0, 0, 0 },
 #endif
 
 { "memcpy()", M_MEMCPY, 0, 0,   memcpy_x_compress, 0,
-                                memcpy_x_compress, 0, 0, 0, 0, 0 },
+                                memcpy_x_compress, 0, 0, 0, 0, 0, 0, 0 },
 { "memset()", M_MEMSET, 0, 0,   memset_x_compress, 0,
-                                memset_x_compress, 0, 0, 0, 0, 0 },
+                                memset_x_compress, 0, 0, 0, 0, 0, 0, 0 },
 { "adler32()", M_ADLER32, 0, 0, adler32_x_compress, 0,
-                                adler32_x_compress, 0, 0, 0, 0, 0 },
+                                adler32_x_compress, 0, 0, 0, 0, 0, 0, 0 },
 { "crc32()", M_CRC32, 0, 0,     crc32_x_compress, 0,
-                                crc32_x_compress, 0, 0, 0, 0, 0 },
+                                crc32_x_compress, 0, 0, 0, 0, 0, 0, 0 },
 #if defined(HAVE_ZLIB_H)
 { "z_adler32()", M_Z_ADLER32, 0, 0, zlib_adler32_x_compress, 0,
-                                zlib_adler32_x_compress, 0, 0, 0, 0, 0 },
+                                zlib_adler32_x_compress, 0, 0, 0, 0, 0, 0, 0 },
 { "z_crc32()", M_Z_CRC32, 0, 0, zlib_crc32_x_compress, 0,
-                                zlib_crc32_x_compress, 0, 0, 0, 0, 0 },
+                                zlib_crc32_x_compress, 0, 0, 0, 0, 0, 0, 0 },
 #endif
 
 #if defined(MFX)
