@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -502,7 +502,7 @@ compress_t;
 
 static const compress_t compress_database[] = {
 #include "db.h"
-{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 }
+{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 }
 };
 
 
@@ -693,13 +693,12 @@ int do_compress ( const compress_t *c,
 
 	if (c && c->compress && WRK_LEN >= c->mem_compress)
 	{
-#if defined(__BOUNDS_CHECKING_ON) || defined(__CHECKER__)
+#if defined(__LZO_CHECKER)
 		/* malloc a block of the exact size to detect any overrun */
 		lzo_byte *w = wrkmem;
 		if (c->mem_compress > 0)
 		{
 			wrkmem = malloc(c->mem_compress);
-#if defined(__CHECKER__)
 			/* must initialize memory - fill in garbage */
 			{
 				lzo_uint32 i;
@@ -708,7 +707,6 @@ int do_compress ( const compress_t *c,
 				for (i = 0; i < c->mem_compress; i++, random_byte += 2)
 					wrkmem[i] = random_byte;
 			}
-#endif
 		}
 		else
 			wrkmem = NULL;
@@ -722,7 +720,7 @@ int do_compress ( const compress_t *c,
 		else
 			r = c->compress(src,src_len,dst,dst_len,wrkmem);
 
-#if defined(__BOUNDS_CHECKING_ON) || defined(__CHECKER__)
+#if defined(__LZO_CHECKER)
 		if (wrkmem)
 			free(wrkmem);
 		wrkmem = w;
@@ -1029,7 +1027,7 @@ int process_file ( const compress_t *c, lzo_decompress_t decompress,
 	t_start = my_clock();
 	for (i = 0; i < t_loops; i++)
 	{
-		lzo_uint len, c_len, c_len_max, d_len;
+		lzo_uint len, c_len, c_len_max, d_len = 0;
 		lzo_byte *d = data;
 
 		len = l;
@@ -1044,7 +1042,7 @@ int process_file ( const compress_t *c, lzo_decompress_t decompress,
 
 			const lzo_uint bl = len > opt_block_size ? opt_block_size : len;
 			lzo_uint bl_overwrite = bl;
-#if defined(__BOUNDS_CHECKING_ON) || defined(__CHECKER__)
+#if defined(__LZO_CHECKER)
 			lzo_byte *dd = NULL;
 			lzo_byte *b1 = NULL;
 			lzo_byte *b2 = NULL;
@@ -1064,7 +1062,7 @@ int process_file ( const compress_t *c, lzo_decompress_t decompress,
 			if (opt_use_asm_fast_decompressor)
 				bl_overwrite += (lzo_uint) sizeof(int) - 1;
 
-#if defined(__BOUNDS_CHECKING_ON) || defined(__CHECKER__)
+#if defined(__LZO_CHECKER)
 			/* malloc a block of the exact size to detect any overrun */
 			dd = malloc(bl_overwrite > 0 ? bl_overwrite : 1);
 			b1 = malloc(b1_len);
@@ -1120,7 +1118,7 @@ int process_file ( const compress_t *c, lzo_decompress_t decompress,
 #endif
 
 		/* decompress the block and verify */
-#if defined(__BOUNDS_CHECKING_ON) || defined(__CHECKER__)
+#if defined(__LZO_CHECKER)
 			lzo_memset(b2,0,bl_overwrite);
 #else
 			init_mem_checker(b2,_block2,bl_overwrite,random_byte);
@@ -1185,7 +1183,7 @@ int process_file ( const compress_t *c, lzo_decompress_t decompress,
 				}
 			}
 
-#if defined(__BOUNDS_CHECKING_ON) || defined(__CHECKER__)
+#if defined(__LZO_CHECKER)
 			/* free in reverse order of allocations */
 			free(b1);
 			free(dd);
@@ -1906,7 +1904,7 @@ int main(int argc, char *argv[])
 
 	printf("\nLZO real-time data compression library (v%s, %s).\n",
 	        LZO_VERSION_STRING, LZO_VERSION_DATE);
-	printf("Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer\n\n");
+	printf("Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer\n\n");
 
 	if (lzo_init() != LZO_E_OK)
 	{
