@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -363,7 +363,7 @@ do_compress    ( const lzo_byte *in , lzo_uint  in_len,
 
 	/* init dictionary */
 #if defined(LZO_DETERMINISTIC)
-	BZERO8_PTR(dict,sizeof(lzo_dict_t),D_SIZE);
+	BZERO8_PTR(wrkmem,sizeof(lzo_dict_t),D_SIZE);
 #endif
 
 	DVAL_FIRST(dv,ip);
@@ -506,7 +506,7 @@ match:
 				assert(ip <= in_end);
 				assert(ii == ip - MIN_MATCH_LONG);
 
-#if defined(__BOUNDS_CHECKING_ON)
+#if defined(__LZO_CHECKER)
 				if (in_end - ip <= (MAX_MATCH_LONG - MIN_MATCH_LONG))
 #else
 				if (in_end <= ip + (MAX_MATCH_LONG - MIN_MATCH_LONG))
