@@ -1,4 +1,5 @@
-#! /bin/sh -e
+#! /bin/sh
+set -e
 
 #
 # usage: util/checkasm.sh [directory]
@@ -7,7 +8,7 @@
 # on a complete directory tree.
 # It is not suitable for accurate timings.
 #
-# Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer
+# Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
 #
 
 LTEST="ltest"
