@@ -1,11 +1,12 @@
-#! /bin/sh -e
+#! /bin/sh
+set -e
 
 #
 # usage: util/overlap.sh [directory]
 #
 # This script runs the overlap example program on a complete directory tree.
 #
-# Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer
+# Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
 #
 
 OVERLAP="overlap"
